fn hash_item_create_sql(catalog: &Catalog, id: CatalogItemId) -> Option<u64>Expand description
Returns the hash of id’s create_sql, or None if the catalog has no such entry.
fn hash_item_create_sql(catalog: &Catalog, id: CatalogItemId) -> Option<u64>Returns the hash of id’s create_sql, or None if the catalog has no such entry.